diff --git a/src/cal_tools/calcat_interface2.py b/src/cal_tools/calcat_interface2.py
index 256f034847a56bcbbc3335dcf1680d81f5b9fb4d..358cc347d1ee9e8c430abc66d15a4eb88e4941a5 100644
--- a/src/cal_tools/calcat_interface2.py
+++ b/src/cal_tools/calcat_interface2.py
@@ -484,7 +484,7 @@ class MultiModuleConstant(Mapping):
             modules = self.qm_names
         else:
             raise ValueError(
-                f"{module_naming=} (must be 'aggregator', 'modnum' or 'qm'"
+                f"{module_naming=} (must be 'aggregator', 'modnum' or 'qm')"
             )
 
         ndarr = self.ndarray(caldb_root, parallel=parallel)
@@ -810,12 +810,15 @@ class CalibrationData(Mapping):
         return type(self)(constant_groups, module_details, det_name)
 
     def summary_table(self, module_naming="modnum"):
-        """Make a markdown table overview of the constants found.
+        """Make a table overview of the constants found.
 
         Columns are calibration types, rows are modules.
         If there are >4 calibrations, the table will be split up into several
         pieces with up to 4 calibrations in each.
 
+	The table(s) returned should be rendered within Jupyter notebooks,
+	including when converting them to Latex & PDF.
+
         Args:
             module_naming (str): modnum, aggregator or qm, to change how the
                 modules are labelled in the table. Defaults to modnum.
@@ -891,7 +894,7 @@ class CalibrationData(Mapping):
             modules = self.qm_names
         else:
             raise ValueError(
-                f"{module_naming=} (must be 'aggregator', 'modnum' or 'qm'"
+                f"{module_naming=} (must be 'aggregator', 'modnum' or 'qm')"
             )
 
         cal_groups = [
@@ -932,16 +935,13 @@ class CalibrationData(Mapping):
         return '\n\n'.join(md_tables)
 
     def display_markdown_table(self, module_naming="modnum"):
         """Make a markdown table overview of the constants found.
 
         Columns are calibration types, rows are modules.
         If there are >4 calibrations, the table will be split up into several
         pieces with up to 4 calibrations in each.
 
         Args:
-            ccvs_url (str, optional): URL for calibration constant versions.
-                Defaults to
-                "https://in.xfel.eu/calibration/calibration_constant_versions/".
             module_naming (str): modnum, aggregator or qm, to change how the
                 modules are labelled in the table. Defaults to modnum.
         """
@@ -932,16 +935,13 @@ class CalibrationData(Mapping):
 
     def display_markdown_table(self, module_naming="modnum"):
-        """Make a markdown table overview of the constants found.
+        """Display a table of the constants found (in a Jupyter notebook).
 
         Columns are calibration types, rows are modules.